@@ -52,7 +52,7 @@ class DashboardElement(MetricsLayerBase):
         return self.filters
 
     def parsed_filters(self, json_safe=False):
-        to_add = {"week_start_day": self.get_model().week_start_day}
+        to_add = {"week_start_day": self.get_model().week_start_day, "timezone": self.project.timezone}
         return [f for raw in self._raw_filters() for f in Filter({**raw, **to_add}).filter_dict(json_safe)]
 
     def collect_errors(self):
@@ -141,13 +141,14 @@ class Dashboard(MetricsLayerBase):
 
     def parsed_filters(self, json_safe=False):
         all_filters = []
+        info = {"timezone": self.project.timezone}
         week_start_days = set(m.week_start_day for m in self.project.models())
         if len(week_start_days) == 1:
-            week_start_day = {"week_start_day": week_start_days.pop()}
+            info["week_start_day"] = week_start_days.pop()
         else:
-            week_start_day = {"week_start_day": None}
+            info["week_start_day"] = None
         for f in self._raw_filters():
-            clean_filters = Filter({**f, **week_start_day}).filter_dict(json_safe)
+            clean_filters = Filter({**f, **info}).filter_dict(json_safe)
             for clean_filter in clean_filters:
                 all_filters.append(clean_filter)
         return all_filters
